@@ -11,8 +11,7 @@ func (m PagerModeNotFound) drawFooter(_ string, _ string) {
 }
 
 func (m PagerModeNotFound) onKey(key twin.KeyCode) {
-	//nolint:gosimple // The linter's advice is just wrong here
-	m.pager.mode = PagerModeViewing{pager: m.pager}
+	m.pager.mode = PagerModeViewing(m)
 	m.pager.mode.onKey(key)
 }
 
@@ -28,8 +27,7 @@ func (m PagerModeNotFound) onRune(char rune) {
 		m.pager.scrollToPreviousSearchHit()
 
 	default:
-		//nolint:gosimple // The linter's advice is just wrong here
-		m.pager.mode = PagerModeViewing{pager: m.pager}
+		m.pager.mode = PagerModeViewing(m)
 		m.pager.mode.onRune(char)
 	}
 }
