@@ -1,6 +1,7 @@
 package m
 
 import (
+	"os"
 	"testing"
 
 	"github.com/alecthomas/chroma/v2"
@@ -25,3 +26,11 @@ func TestTwinStyleFromChroma(t *testing.T) {
 			WithAttr(twin.AttrBold).
 			WithForeground(twin.NewColor24Bit(0xe2, 0xe4, 0xe5)))
 }
+
+func TestSetStyle(t *testing.T) {
+	assert.NilError(t, os.Setenv("MOAR_TEST_STYLE", "\x1b[1;31m"))
+	style := twin.StyleDefault
+	setStyle(&style, "MOAR_TEST_STYLE", nil)
+
+	assert.Equal(t, style, twin.StyleDefault.WithAttr(twin.AttrBold).WithForeground(twin.NewColor16(1)))
+}
